| isProcessForkedChild | R Documentation |
Returns TRUE if the current process is a fork() of the process in which
RcppParallel was originally loaded.
isProcessForkedChild()
Intel TBB — the parallel backend used by parallelFor() and
parallelReduce() — does not support being used in a child process after
fork(). Packages that may be invoked from within parallel::mclapply()
or similar fork-based parallelism should call isProcessForkedChild() and
fall back to a serial code path when it returns TRUE.
On Windows, which has no fork(), this always returns FALSE.
A length-one logical.
## Not run:
library(RcppParallel)
isProcessForkedChild()
parallel::mclapply(1:2, function(i) RcppParallel::isProcessForkedChild())
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.